@@ -1,7 +1,7 @@
 /*
  *  signing.c
  *
- *  Copyright (c) 2008-2019 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2008-2020 Pacman Development Team <pacman-dev@archlinux.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -479,7 +479,7 @@ static int email_from_uid(const char *uid, char **email)
        char *start, *end;
 
        if (uid == NULL) {
-               email = NULL;
+               *email = NULL;
                return -1;
        }
 
@@ -492,7 +492,7 @@ static int email_from_uid(const char *uid, char **email)
                STRNDUP(*email, start+1, end-start-1, return -1);
                return 0;
        } else {
-               email = NULL;
+               *email = NULL;
                return -1;
        }
 }
@@ -1098,7 +1098,7 @@ static int parse_subpacket(alpm_handle_t *handle, const char *identifier,
 				if(length_check(len, spos, 2, handle, identifier) != 0){
 					return -1;
 				}
-				slen = (sig[spos] << 8) | sig[spos + 1];
+				slen = ((sig[spos] - 192) << 8) + sig[spos + 1] + 192;
 				spos = spos + 2;
 			} else {
 				if(length_check(len, spos, 5, handle, identifier) != 0) {
